Index: /trunk/include/VBox/com/string.h
===================================================================
--- /trunk/include/VBox/com/string.h	(revision 52553)
+++ /trunk/include/VBox/com/string.h	(revision 52554)
@@ -514,7 +514,7 @@
     }
 
-    Utf8Str(CBSTR that, size_t a_cchSize = RTSTR_MAX)
-    {
-        copyFrom(that, a_cchSize);
+    Utf8Str(CBSTR that, size_t a_cwcSize = RTSTR_MAX)
+    {
+        copyFrom(that, a_cwcSize);
     }
 
@@ -718,5 +718,5 @@
 protected:
 
-    void copyFrom(CBSTR a_pbstr, size_t a_cchSize = RTSTR_MAX);
+    void copyFrom(CBSTR a_pbstr, size_t a_cwcMax = RTSTR_MAX);
     HRESULT copyFromEx(CBSTR a_pbstr);
     HRESULT copyFromExNComRC(const char *a_pcszSrc, size_t a_offSrc, size_t a_cchSrc);
Index: /trunk/src/VBox/Main/glue/string.cpp
===================================================================
--- /trunk/src/VBox/Main/glue/string.cpp	(revision 52553)
+++ /trunk/src/VBox/Main/glue/string.cpp	(revision 52554)
@@ -179,15 +179,15 @@
  * @param   a_pbstr         The source string.  The caller guarantees that this
  *                          is valid UTF-16.
  * @param   a_cbSize        The number of characters to be copied. If set to RTSTR_MAX,
  *                          the entire string will be copied.
  *
  * @sa      RTCString::copyFromN
  */
-void Utf8Str::copyFrom(CBSTR a_pbstr, size_t a_cchSize)
+void Utf8Str::copyFrom(CBSTR a_pbstr, size_t a_cwcMax)
 {
     if (a_pbstr && *a_pbstr)
     {
         int vrc = RTUtf16ToUtf8Ex((PCRTUTF16)a_pbstr,
-                                  a_cchSize,        // size_t cwcString: translate entire string
+                                  a_cwcMax,        // size_t cwcString: translate entire string
                                   &m_psz,           // char **ppsz: output buffer
                                   0,                // size_t cch: if 0, func allocates buffer in *ppsz
@@ -179,15 +179,15 @@
  * @param   a_pbstr         The source string.  The caller guarantees that this
  *                          is valid UTF-16.
- * @param   a_cbSize        The number of characters to be copied. If set to RTSTR_MAX,
+ * @param   a_cwcMax        The number of characters to be copied. If set to RTSTR_MAX,
  *                          the entire string will be copied.
  *
